const n=d(/[A-Za-z]/),t=d(/[\dA-Za-z]/),u=d(/[#-'*+\--9=?A-Z^-~]/);function a(n){return null!==n&&(n<32||127===n)}const s=d(/\d/),r=d(/[\dA-Fa-f]/),o=d(/[!-/:-@[-`{-~]/);function c(n){return null!==n&&n<-2}function e(n){return null!==n&&(n<0||32===n)}function f(n){return-2===n||-1===n||32===n}const i=d(/\p{P}|\p{S}/u),l=d(/\s/);function d(n){return function(t){return null!==t&&t>-1&&n.test(String.fromCharCode(t))}}export{i as a,n as b,t as c,a as d,u as e,f,o as g,r as h,s as i,e as j,c as m,l as u};
