import{g as r}from"./ansi-regex-DJPe--rM.js";var t,e;var o=function(){if(e)return t;e=1;var r=Object.prototype.hasOwnProperty,o=Object.prototype.toString,n=Object.defineProperty,a=Object.getOwnPropertyDescriptor,c=function(r){return"function"==typeof Array.isArray?Array.isArray(r):"[object Array]"===o.call(r)},u=function(t){if(!t||"[object Object]"!==o.call(t))return!1;var e,n=r.call(t,"constructor"),a=t.constructor&&t.constructor.prototype&&r.call(t.constructor.prototype,"isPrototypeOf");if(t.constructor&&!n&&!a)return!1;for(e in t);return void 0===e||r.call(t,e)},i=function(r,t){n&&"__proto__"===t.name?n(r,t.name,{enumerable:!0,configurable:!0,value:t.newValue,writable:!0}):r[t.name]=t.newValue},l=function(t,e){if("__proto__"===e){if(!r.call(t,e))return;if(a)return a(t,e).value}return t[e]};return t=function r(){var t,e,o,n,a,f,p=arguments[0],y=1,s=arguments.length,b=!1;for("boolean"==typeof p&&(b=p,p=arguments[1]||{},y=2),(null==p||"object"!=typeof p&&"function"!=typeof p)&&(p={});y<s;++y)if(null!=(t=arguments[y]))for(e in t)o=l(p,e),p!==(n=l(t,e))&&(b&&n&&(u(n)||(a=c(n)))?(a?(a=!1,f=o&&c(o)?o:[]):f=o&&u(o)?o:{},i(p,{name:e,newValue:r(b,f,n)})):void 0!==n&&i(p,{name:e,newValue:n}));return p},t}();const n=r(o);export{n as e};
