import{d as n,m as e,j as t}from"./micromark-util-character-DUwsRT9L.js";function r(r,u,i,c,o,s,m,f,x){const l=x||Number.POSITIVE_INFINITY;let a=0;return function(e){if(60===e)return r.enter(c),r.enter(o),r.enter(s),r.consume(e),r.exit(s),g;if(null===e||32===e||41===e||n(e))return i(e);return r.enter(c),r.enter(m),r.enter(f),r.enter("chunkString",{contentType:"string"}),I(e)};function g(n){return 62===n?(r.enter(s),r.consume(n),r.exit(s),r.exit(o),r.exit(c),u):(r.enter(f),r.enter("chunkString",{contentType:"string"}),h(n))}function h(n){return 62===n?(r.exit("chunkString"),r.exit(f),g(n)):null===n||60===n||e(n)?i(n):(r.consume(n),92===n?k:h)}function k(n){return 60===n||62===n||92===n?(r.consume(n),h):h(n)}function I(e){return a||null!==e&&41!==e&&!t(e)?a<l&&40===e?(r.consume(e),a++,I):41===e?(r.consume(e),a--,I):null===e||32===e||40===e||n(e)?i(e):(r.consume(e),92===e?S:I):(r.exit("chunkString"),r.exit(f),r.exit(m),r.exit(c),u(e))}function S(n){return 40===n||41===n||92===n?(r.consume(n),I):I(n)}}export{r as f};
