import{g as t,a}from"./mdast-util-gfm-autolink-literal-CV8rYkCl.js";import{g as s,a as m}from"./mdast-util-gfm-footnote-Cugz-_6P.js";import{g as o,a as i}from"./mdast-util-gfm-strikethrough-CppM9lzQ.js";import{g as r,a as f}from"./mdast-util-gfm-table-CfHUi3P6.js";import{g,a as u}from"./mdast-util-gfm-task-list-item-B6deDowo.js";function e(){return[t(),s(),o(),r(),g()]}function l(t){return{extensions:[a(),m(t),i(),f(t),u()]}}export{l as a,e as g};
