import{f as n}from"./micromark-factory-space-O0Sojo8n.js";import{m as e}from"./micromark-util-character-DUwsRT9L.js";function t(t,r,i,u,c,o){let m;return function(n){if(34===n||39===n||40===n)return t.enter(u),t.enter(c),t.consume(n),t.exit(c),m=40===n?41:n,f;return i(n)};function f(n){return n===m?(t.enter(c),t.consume(n),t.exit(c),t.exit(u),r):(t.enter(o),s(n))}function s(r){return r===m?(t.exit(o),f(m)):null===r?i(r):e(r)?(t.enter("lineEnding"),t.consume(r),t.exit("lineEnding"),n(t,s,"linePrefix")):(t.enter("chunkString",{contentType:"string"}),a(r))}function a(n){return n===m||null===n||e(n)?(t.exit("chunkString"),s(n)):(t.consume(n),92===n?l:a)}function l(n){return n===m||92===n?(t.consume(n),a):a(n)}}export{t as f};
