import{g as e}from"./ansi-regex-DJPe--rM.js";import{r as t}from"./style-to-object-Drm57gnD.js";var r,n,o,a={};function u(){if(r)return a;r=1,Object.defineProperty(a,"__esModule",{value:!0}),a.camelCase=void 0;var e=/^--[a-zA-Z0-9_-]+$/,t=/-([a-z])/g,n=/^[^-]+$/,o=/^-(webkit|moz|ms|o|khtml)-/,u=/^-(ms)-/,c=function(e,t){return t.toUpperCase()},s=function(e,t){return"".concat(t,"-")};return a.camelCase=function(r,a){return void 0===a&&(a={}),function(t){return!t||n.test(t)||e.test(t)}(r)?r:(r=r.toLowerCase(),(r=a.reactCompat?r.replace(u,s):r.replace(o,s)).replace(t,c))},a}const c=e(function(){if(o)return n;o=1;var e=(n&&n.__importDefault||function(e){return e&&e.__esModule?e:{default:e}})(t()),r=u();function a(t,n){var o={};return t&&"string"==typeof t?((0,e.default)(t,function(e,t){e&&t&&(o[(0,r.camelCase)(e,n)]=t)}),o):o}return a.default=a,n=a}());export{c as s};
