import{f as r}from"./micromark-util-character-DUwsRT9L.js";function t(t,n,e,u){const o=u?u-1:Number.POSITIVE_INFINITY;let c=0;return function(u){if(r(u))return t.enter(e),i(u);return n(u)};function i(u){return r(u)&&c++<o?(t.consume(u),i):(t.exit(e),n(u))}}export{t as f};
