import{f as e}from"./micromark-factory-space-O0Sojo8n.js";import{j as t,m as n,f as r}from"./micromark-util-character-DUwsRT9L.js";const s={name:"tasklistCheck",tokenize:function(e,s,c){const k=this;return function(t){if(null!==k.previous||!k._gfmTasklistFirstContentOfListItem)return c(t);return e.enter("taskListCheck"),e.enter("taskListCheckMarker"),e.consume(t),e.exit("taskListCheckMarker"),a};function a(n){return t(n)?(e.enter("taskListCheckValueUnchecked"),e.consume(n),e.exit("taskListCheckValueUnchecked"),u):88===n||120===n?(e.enter("taskListCheckValueChecked"),e.consume(n),e.exit("taskListCheckValueChecked"),u):c(n)}function u(t){return 93===t?(e.enter("taskListCheckMarker"),e.consume(t),e.exit("taskListCheckMarker"),e.exit("taskListCheck"),o):c(t)}function o(t){return n(t)?s(t):r(t)?e.check({tokenize:i},s,c)(t):c(t)}}};function c(){return{text:{91:s}}}function i(t,n,r){return e(t,function(e){return null===e?r(e):n(e)},"whitespace")}export{c as g};
