function t(t,e){const n=String(t);let r=n.indexOf(e),i=r,o=0,f=0;if("string"!=typeof e)throw new TypeError("Expected substring");for(;-1!==r;)r===i?++o>f&&(f=o):o=1,i=r+e.length,r=n.indexOf(e,i);return f}export{t as l};
