import{v as t}from"./unist-util-visit-parents-DrBR4cjY.js";function n(n,i,o,e){let f,r,s;"function"==typeof i&&"function"!=typeof o?(r=void 0,s=i,f=o):(r=i,s=o,f=e),t(n,r,function(t,n){const i=n[n.length-1],o=i?i.children.indexOf(t):void 0;return s(t,o,i)},f)}export{n as v};
