const n=function(e){if(null==e)return r;if("function"==typeof e)return t(e);if("object"==typeof e)return Array.isArray(e)?function(r){const e=[];let o=-1;for(;++o<r.length;)e[o]=n(r[o]);return t(u);function u(...n){let t=-1;for(;++t<e.length;)if(e[t].apply(this,n))return!0;return!1}}(e):function(n){const r=n;return t(e);function e(t){const e=t;let o;for(o in n)if(e[o]!==r[o])return!1;return!0}}(e);if("string"==typeof e)return function(n){return t(r);function r(t){return t&&t.type===n}}(e);throw new Error("Expected function, string, or object as test")};function t(n){return function(t,r,e){return Boolean(function(n){return null!==n&&"object"==typeof n&&"type"in n}(t)&&n.call(this,t,"number"==typeof r?r:void 0,e||void 0))}}function r(){return!0}export{n as c};
