import{a as e}from"./react-DnjLh4X0.js";import{u as t}from"./use-sync-external-store-BwOntpwp.js";const n=e=>Symbol.iterator in e,o=e=>"entries"in e,r=(e,t)=>{const n=e instanceof Map?e:new Map(e.entries()),o=t instanceof Map?t:new Map(t.entries());if(n.size!==o.size)return!1;for(const[r,s]of n)if(!Object.is(s,o.get(r)))return!1;return!0};function s(e,t){return!!Object.is(e,t)||"object"==typeof e&&null!==e&&"object"==typeof t&&null!==t&&(Object.getPrototypeOf(e)===Object.getPrototypeOf(t)&&(n(e)&&n(t)?o(e)&&o(t)?r(e,t):((e,t)=>{const n=e[Symbol.iterator](),o=t[Symbol.iterator]();let r=n.next(),s=o.next();for(;!r.done&&!s.done;){if(!Object.is(r.value,s.value))return!1;r=n.next(),s=o.next()}return!!r.done&&!!s.done})(e,t):r({entries:()=>Object.entries(e)},{entries:()=>Object.entries(t)})))}const i=e=>{let t;const n=new Set,o=(e,o)=>{const r="function"==typeof e?e(t):e;if(!Object.is(r,t)){const e=t;t=(null!=o?o:"object"!=typeof r||null===r)?r:Object.assign({},t,r),n.forEach(n=>n(t,e))}},r=()=>t,s={setState:o,getState:r,getInitialState:()=>i,subscribe:e=>(n.add(e),()=>n.delete(e))},i=t=e(o,r,s);return s},c=e=>e?i(e):i,{useSyncExternalStoreWithSelector:a}=t,u=e=>e;function l(t,n=u,o){const r=a(t.subscribe,t.getState,t.getInitialState,n,o);return e.useDebugValue(r),r}export{c,s,l as u};
