import{r}from"./inline-style-parser-D8_Zmyug.js";var e,t={};function n(){if(e)return t;e=1;var n=t&&t.__importDefault||function(r){return r&&r.__esModule?r:{default:r}};Object.defineProperty(t,"__esModule",{value:!0}),t.default=function(r,e){var t=null;if(!r||"string"!=typeof r)return t;var n=(0,u.default)(r),a="function"==typeof e;return n.forEach(function(r){if("declaration"===r.type){var n=r.property,u=r.value;a?e(n,u,r):u&&((t=t||{})[n]=u)}}),t};var u=n(r());return t}export{n as r};
