var e,t,r,o,n={exports:{}},c={};function f(){return t||(t=1,n.exports=function(){if(e)return c;e=1;var t="function"==typeof Symbol&&Symbol.for,r=t?Symbol.for("react.element"):60103,o=t?Symbol.for("react.portal"):60106,n=t?Symbol.for("react.fragment"):60107,f=t?Symbol.for("react.strict_mode"):60108,a=t?Symbol.for("react.profiler"):60114,s=t?Symbol.for("react.provider"):60109,y=t?Symbol.for("react.context"):60110,i=t?Symbol.for("react.async_mode"):60111,p=t?Symbol.for("react.concurrent_mode"):60111,u=t?Symbol.for("react.forward_ref"):60112,l=t?Symbol.for("react.suspense"):60113,m=t?Symbol.for("react.suspense_list"):60120,d=t?Symbol.for("react.memo"):60115,b=t?Symbol.for("react.lazy"):60116,$=t?Symbol.for("react.block"):60121,S=t?Symbol.for("react.fundamental"):60117,P=t?Symbol.for("react.responder"):60118,g=t?Symbol.for("react.scope"):60119;function v(e){if("object"==typeof e&&null!==e){var t=e.$$typeof;switch(t){case r:switch(e=e.type){case i:case p:case n:case a:case f:case l:return e;default:switch(e=e&&e.$$typeof){case y:case u:case b:case d:case s:return e;default:return t}}case o:return t}}}function x(e){return v(e)===p}return c.AsyncMode=i,c.ConcurrentMode=p,c.ContextConsumer=y,c.ContextProvider=s,c.Element=r,c.ForwardRef=u,c.Fragment=n,c.Lazy=b,c.Memo=d,c.Portal=o,c.Profiler=a,c.StrictMode=f,c.Suspense=l,c.isAsyncMode=function(e){return x(e)||v(e)===i},c.isConcurrentMode=x,c.isContextConsumer=function(e){return v(e)===y},c.isContextProvider=function(e){return v(e)===s},c.isElement=function(e){return"object"==typeof e&&null!==e&&e.$$typeof===r},c.isForwardRef=function(e){return v(e)===u},c.isFragment=function(e){return v(e)===n},c.isLazy=function(e){return v(e)===b},c.isMemo=function(e){return v(e)===d},c.isPortal=function(e){return v(e)===o},c.isProfiler=function(e){return v(e)===a},c.isStrictMode=function(e){return v(e)===f},c.isSuspense=function(e){return v(e)===l},c.isValidElementType=function(e){return"string"==typeof e||"function"==typeof e||e===n||e===p||e===a||e===f||e===l||e===m||"object"==typeof e&&null!==e&&(e.$$typeof===b||e.$$typeof===d||e.$$typeof===s||e.$$typeof===y||e.$$typeof===u||e.$$typeof===S||e.$$typeof===P||e.$$typeof===g||e.$$typeof===$)},c.typeOf=v,c}()),n.exports}!function(){if(o)return r;o=1;var e=f(),t={childContextTypes:!0,contextType:!0,contextTypes:!0,defaultProps:!0,displayName:!0,getDefaultProps:!0,getDerivedStateFromError:!0,getDerivedStateFromProps:!0,mixins:!0,propTypes:!0,type:!0},n={name:!0,length:!0,prototype:!0,caller:!0,callee:!0,arguments:!0,arity:!0},c={$$typeof:!0,compare:!0,defaultProps:!0,displayName:!0,propTypes:!0,type:!0},a={};function s(r){return e.isMemo(r)?c:a[r.$$typeof]||t}a[e.ForwardRef]={$$typeof:!0,render:!0,defaultProps:!0,displayName:!0,propTypes:!0},a[e.Memo]=c;var y=Object.defineProperty,i=Object.getOwnPropertyNames,p=Object.getOwnPropertySymbols,u=Object.getOwnPropertyDescriptor,l=Object.getPrototypeOf,m=Object.prototype;r=function e(t,r,o){if("string"!=typeof r){if(m){var c=l(r);c&&c!==m&&e(t,c,o)}var f=i(r);p&&(f=f.concat(p(r)));for(var a=s(t),d=s(r),b=0;b<f.length;++b){var $=f[b];if(!(n[$]||o&&o[$]||d&&d[$]||a&&a[$])){var S=u(r,$);try{y(t,$,S)}catch(P){}}}}return t}}();
