const e=["autolink","destinationLiteral","destinationRaw","reference","titleQuote","titleApostrophe"];function t(){return{canContainEols:["delete"],enter:{strikethrough:r},exit:{strikethrough:i}}}function n(){return{unsafe:[{character:"~",inConstruct:"phrasing",notInConstruct:e}],handlers:{delete:o}}}function r(e){this.enter({type:"delete",children:[]},e)}function i(e){this.exit(e)}function o(e,t,n,r){const i=n.createTracker(r),o=n.enter("strikethrough");let a=i.move("~~");return a+=n.containerPhrasing(e,{...i.current(),before:a,after:"~"}),a+=i.move("~~"),o(),a}o.peek=function(){return"~"};export{n as a,t as g};
