import{c as o}from"./micromark-util-combine-extensions-DQ8C0oVl.js";import{g as m}from"./micromark-extension-gfm-autolink-literal-CAZrQ6Ew.js";import{g as r}from"./micromark-extension-gfm-footnote-oiA1MrCk.js";import{g as i}from"./micromark-extension-gfm-strikethrough-D-1Of1Ef.js";import{g as t}from"./micromark-extension-gfm-table-BfKMMIFy.js";import{g as s}from"./micromark-extension-gfm-task-list-item-Bctfj89z.js";function e(e){return o([m(),r(),i(e),t(),s()])}export{e as g};
