var t=Number.isNaN||function(t){return"number"==typeof t&&t!=t};function r(r,n){return r===n||!(!t(r)||!t(n))}function n(t,n){if(t.length!==n.length)return!1;for(var u=0;u<t.length;u++)if(!r(t[u],n[u]))return!1;return!0}function u(t,r){void 0===r&&(r=n);var u=null;function e(){for(var n=[],e=0;e<arguments.length;e++)n[e]=arguments[e];if(u&&u.lastThis===this&&r(n,u.lastArgs))return u.lastResult;var l=t.apply(this,n);return u={lastResult:l,lastArgs:n,lastThis:this},l}return e.clear=function(){u=null},e}export{u as m};
