const n={};function t(t,r){return e(t,"boolean"!=typeof n.includeImageAlt||n.includeImageAlt,"boolean"!=typeof n.includeHtml||n.includeHtml)}function e(n,t,e){if(function(n){return Boolean(n&&"object"==typeof n)}(n)){if("value"in n)return"html"!==n.type||e?n.value:"";if(t&&"alt"in n&&n.alt)return n.alt;if("children"in n)return r(n.children,t,e)}return Array.isArray(n)?r(n,t,e):""}function r(n,t,r){const l=[];let i=-1;for(;++i<n.length;)l[i]=e(n[i],t,r);return l.join("")}export{t};
