const t=function(r){if(null==r)return e;if("string"==typeof r)return function(t){return n(e);function e(n){return n.tagName===t}}(r);if("object"==typeof r)return function(e){const r=[];let o=-1;for(;++o<e.length;)r[o]=t(e[o]);return n(i);function i(...t){let n=-1;for(;++n<r.length;)if(r[n].apply(this,t))return!0;return!1}}(r);if("function"==typeof r)return n(r);throw new Error("Expected function, string, or array as `test`")};function n(t){return function(n,e,r){return Boolean(function(t){return null!==t&&"object"==typeof t&&"type"in t&&"tagName"in t}(n)&&t.call(this,n,"number"==typeof e?e:void 0,r||void 0))}}function e(t){return Boolean(t&&"object"==typeof t&&"type"in t&&"element"===t.type&&"tagName"in t&&"string"==typeof t.tagName)}export{t as c};
