var e="-ms-",n="-moz-",r="-webkit-",a="comm",t="rule",c="decl",u="@keyframes",s=Math.abs,i=String.fromCharCode,f=Object.assign;function o(e,n){return 45^v(e,0)?(((n<<2^v(e,0))<<2^v(e,1))<<2^v(e,2))<<2^v(e,3):0}function l(e){return e.trim()}function h(e,n){return(e=n.exec(e))?e[0]:e}function b(e,n,r){return e.replace(n,r)}function k(e,n){return e.indexOf(n)}function v(e,n){return 0|e.charCodeAt(n)}function d(e,n,r){return e.slice(n,r)}function p(e){return e.length}function g(e){return e.length}function m(e,n){return n.push(e),e}function w(e,n){return e.map(n).join("")}var j=1,y=1,x=0,C=0,M=0,O="";function q(e,n,r,a,t,c,u){return{value:e,root:n,parent:r,type:a,props:t,children:c,line:j,column:y,length:u,return:""}}function z(e,n){return f(q("",null,null,"",null,null,0),e,{length:-e.length},n)}function A(){return M=C>0?v(O,--C):0,y--,10===M&&(y=1,j--),M}function D(){return M=C<x?v(O,C++):0,y++,10===M&&(y=1,j++),M}function K(){return v(O,C)}function R(){return C}function S(e,n){return d(O,e,n)}function W(e){switch(e){case 0:case 9:case 10:case 13:case 32:return 5;case 33:case 43:case 44:case 47:case 62:case 64:case 126:case 59:case 123:case 125:return 4;case 58:return 3;case 34:case 39:case 40:case 91:return 2;case 41:case 93:return 1}return 0}function B(e){return j=y=1,x=p(O=e),C=0,[]}function E(e){return O="",e}function F(e){return l(S(C-1,I(91===e?e+2:40===e?e+1:e)))}function G(e){for(;(M=K())&&M<33;)D();return W(e)>2||W(M)>3?"":" "}function H(e,n){for(;--n&&D()&&!(M<48||M>102||M>57&&M<65||M>70&&M<97););return S(e,R()+(n<6&&32==K()&&32==D()))}function I(e){for(;D();)switch(M){case e:return C;case 34:case 39:34!==e&&39!==e&&I(M);break;case 40:41===e&&I(e);break;case 92:D()}return C}function J(e,n){for(;D()&&e+M!==57&&(e+M!==84||47!==K()););return"/*"+S(n,C-1)+"*"+i(47===e?e:D())}function L(e){for(;!W(K());)D();return S(e,C)}function N(e){return E(P("",null,null,null,[""],e=B(e),0,[0],e))}function P(e,n,r,a,t,c,u,s,f){for(var o=0,l=0,h=u,d=0,g=0,w=0,j=1,y=1,x=1,C=0,M="",O=t,q=c,z=a,S=M;y;)switch(w=C,C=D()){case 40:if(108!=w&&58==v(S,h-1)){-1!=k(S+=b(F(C),"&","&\f"),"&\f")&&(x=-1);break}case 34:case 39:case 91:S+=F(C);break;case 9:case 10:case 13:case 32:S+=G(w);break;case 92:S+=H(R()-1,7);continue;case 47:switch(K()){case 42:case 47:m(T(J(D(),R()),n,r),f);break;default:S+="/"}break;case 123*j:s[o++]=p(S)*x;case 125*j:case 59:case 0:switch(C){case 0:case 125:y=0;case 59+l:-1==x&&(S=b(S,/\f/g,"")),g>0&&p(S)-h&&m(g>32?U(S+";",a,r,h-1):U(b(S," ","")+";",a,r,h-2),f);break;case 59:S+=";";default:if(m(z=Q(S,n,r,o,l,t,s,M,O=[],q=[],h),c),123===C)if(0===l)P(S,n,z,z,O,c,h,s,q);else switch(99===d&&110===v(S,3)?100:d){case 100:case 108:case 109:case 115:P(e,z,z,a&&m(Q(e,z,z,0,0,t,s,M,t,O=[],h),q),t,q,h,s,a?O:q);break;default:P(S,z,z,z,[""],q,0,s,q)}}o=l=g=0,j=x=1,M=S="",h=u;break;case 58:h=1+p(S),g=w;default:if(j<1)if(123==C)--j;else if(125==C&&0==j++&&125==A())continue;switch(S+=i(C),C*j){case 38:x=l>0?1:(S+="\f",-1);break;case 44:s[o++]=(p(S)-1)*x,x=1;break;case 64:45===K()&&(S+=F(D())),d=K(),l=h=p(M=S+=L(R())),C++;break;case 45:45===w&&2==p(S)&&(j=0)}}return c}function Q(e,n,r,a,c,u,i,f,o,h,k){for(var v=c-1,p=0===c?u:[""],m=g(p),w=0,j=0,y=0;w<a;++w)for(var x=0,C=d(e,v+1,v=s(j=i[w])),M=e;x<m;++x)(M=l(j>0?p[x]+" "+C:b(C,/&\f/g,p[x])))&&(o[y++]=M);return q(e,n,r,0===c?t:f,o,h,k)}function T(e,n,r){return q(e,n,r,a,i(M),d(e,2,-2),0)}function U(e,n,r,a){return q(e,n,r,c,d(e,0,a),d(e,a+1,-1),a)}function V(e,n){for(var r="",a=g(e),t=0;t<a;t++)r+=n(e[t],t,e,n)||"";return r}function X(e,n,r,s){switch(e.type){case"@layer":if(e.children.length)break;case"@import":case c:return e.return=e.return||e.value;case a:return"";case u:return e.return=e.value+"{"+V(e.children,s)+"}";case t:e.value=e.props.join(",")}return p(r=V(e.children,s))?e.return=e.value+"{"+r+"}":""}function Y(e){var n=g(e);return function(r,a,t,c){for(var u="",s=0;s<n;s++)u+=e[s](r,a,t,c)||"";return u}}function Z(e){return function(n){n.root||(n=n.return)&&e(n)}}export{c as D,u as K,e as M,t as R,r as W,X as a,w as b,N as c,z as d,b as e,E as f,B as g,o as h,v as i,p as j,k,n as l,Y as m,h as n,D as o,i as p,K as q,Z as r,V as s,W as t,F as u,S as v,C as w};
