function t(t){const n=String(t),o=/\r?\n|\r/g;let i=o.exec(n),c=0;const r=[];for(;i;)r.push(e(n.slice(c,i.index),c>0,!0),i[0]),c=i.index+i[0].length,i=o.exec(n);return r.push(e(n.slice(c),c>0,!1)),r.join("")}function e(t,e,n){let o=0,i=t.length;if(e){let e=t.codePointAt(o);for(;9===e||32===e;)o++,e=t.codePointAt(o)}if(n){let e=t.codePointAt(i-1);for(;9===e||32===e;)i--,e=t.codePointAt(i-1)}return i>o?t.slice(o,i):""}export{t};
